within FluidDissipation.HeatTransfer.HeatExchanger;
function kc_tubeBundle_1ph
  "Heat transfer for a lateral flow through a tube row or a bundle of staggered or inline tube rows (laminar and turbulent flow schemes)"
  extends Modelica.Icons.Function;
  //SOURCE: Gnielinski, V.. Heat Transfer in laterally passed single tube rows and tube bundles (in German). in VDI-Waermeatlas, 9th edition, VDI-Verlag, 2002.
  //input records
  input FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_IN_con IN_con
    "Input record for function kc_FilmCondensationTubeBundle"
    annotation (Dialog(group="Constant inputs"));
  input FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_IN_var IN_var
    "Input record for function kc_FilmCondensationTubeBundle"
    annotation (Dialog(group="Variable inputs"));

  output Modelica.SIunits.CoefficientOfHeatTransfer kc
    "Heat transfer coefficient";
  output Modelica.SIunits.PrandtlNumber Pr "Prandtl number of fluid";
  output Modelica.SIunits.ReynoldsNumber Re_L "Reynolds number";
  output Modelica.SIunits.NusseltNumber Nu_L "Nusselt number of row or bundle";
  output Real failureStatus
    "0== boundary conditions fulfilled | 1== failure >> check if still meaningful results";

protected
  Real MIN=1e-5;
  SI.Length L "Characteristic length";
  Real a "Alignment ratio orthogonal to flow direction";
  Real b "Alignment ratio parallel to flow direction";
  Real psi "Void ratio";
algorithm

  a:=IN_con.s_1/IN_con.d;
  b:=IN_con.s_2/IN_con.d;
  // b<=0 refers to single row case!
  psi:=if b >= 1 or b<=0 then 1 - Modelica.Constants.pi/4/a else 1 - Modelica.Constants.pi/4/a/b;
  L:= Modelica.Constants.pi/2*IN_con.d;
  Re_L :=abs(IN_var.m_flow)/IN_con.A_front/IN_var.rho*L/psi/IN_var.eta*IN_var.rho;
  Pr   :=IN_var.eta*IN_var.cp/max(MIN,IN_var.lambda);

  kc := FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_KC(IN_con, IN_var);
  Nu_L := max(1e-3, kc*L/IN_var.lambda);

  failureStatus := if (Re_L<10e6 and Re_L>10) and (Pr<10e3 and Pr>0.6)  then 0 else 1;

  annotation (Documentation(info="<html>
<p>
Calculation of the mean heat transfer coefficient <b> kc </b> for laterally passed single tube rows and tube bundles.
</p>

<h4><font color=\"#EF9B13\">Restriction</font></h4>
<ul>

<li> single-phase medium  </li>

<li> 10 &lt; Re_psi_L &lt; 1e6</li>

<li> 0.6 &lt; Pr &lt; 1e3</li>

</ul>

<h4><font color=\"#EF9B13\">Geometry </font></h4>
<p>
<img src=\"modelica://FluidDissipation/Extras/Images/heatTransfer/heatExchanger/pic_tubeBundle.png\", width=850>
</p> 

<h4><font color=\"#EF9B13\">Calculation</font></h4>
<p>
The mean heat transfer coefficient <b> kc </b> for a single row of tubes or a tube bundle is calculated through the corresponding Nusselt number <b> Nu_lam</b> according to <i>[VDI 2002, p. Gg 1, eq. 3]</i> :
</p>

<pre>
    Nu_lam = 0.664 * Re_psi_L^0.5 * Pr^(1/3)
</pre>
 
<p>
with the corresponding mean heat transfer coefficient <b> kc </b> :
</p>
 
<p>
<pre>
    kc =  Nu * lambda / L
</pre>
</p>
 
<p>
whereas <b> L </b> equals half of the tubes circumference and for the non-dimensional Reynolds number <b> Re_psi_L </b> holds:
</p>

<p>
<pre>
    Re_psi_L =  (w0 * L * rho) / (psi * eta)
</pre>
</p>

<p>
The void fraction <b> psi </b> of the tube bundle is calculated for different longitudinal (i.e., in-flow) alignment ratios <b> b </b> = s_2/d_a:
</p>

<p>
<pre>
    psi = 1 - pi / (4 * a) if b &ge; 1
</pre>
</p>

<p>
<pre>
    psi = 1 - pi / (4 * a * b) if b &lt; 1 
</pre>
</p>

<p>
For the turbulent contribution <b> Nu_turb </b> equals:
</p>

<p>
<pre>
    Nu_turb = 0.037 * Re_psi_L^1^0.8 * Pr / (1 + 2.443 * Re_psi_L^(-0.1) * (Pr^(2/3) - 1)).
<pre>
</p>

<h4> Single row of tubes </h4>

<p> The superposition of the laminar and turbulent part yields for a single row of tubes:</p>

<p>
<pre>
    Nu_0,row = 0.3 + (Nu_lam^2 + Nu_turb^2)^(-0.5).
<pre>
</p>

<h4> Bundle of tube rows </h4>

<p> Depending on the row arrangement the Nusselt number is scaled with an arrangement factor <b>fa</b>:</p>

<p><i> Inline arrangement </i></p>

<p>
<pre>
    fa = 1 + 0.7 / psi^1.5 * (b/a - 0.3) / (b/a + 0.7)^2 
<pre>
</p>

<p><i> Staggered arrangement </i></p>

<p>
<pre>
    fa = 1 + 2 / (3*b)
<pre>
</p>

<p>which yields for <b> more </b> than 10 rows:</p>

<p>
<pre>
    Nu_bundle = fa * Nu_L,0.
<pre>
</p>

<p> <b>Less</b> than 10 rows are scaled with an additional factor:</p>

<p>
<pre>
    Nu_bundle =  (1 + (n - 1)*fa) / n * Nu_L,0.
<pre>
</p>


<p>
with
</p>
 
<p>
<table>
<tr><td><b> C                        </b></td><td> as Correction factor for tube arrangement: offset pattern=1| aligned pattern=0.8 [-], </td></tr>
<tr><td><b> cp_l                        </b></td><td> as specific heat capacity of liquid at constant pressure [J/(kg.K)],</td></tr>
<tr><td><b> d                        </b></td><td> as tube diameter [m],</td></tr>
<tr><td><b> eta_l                        </b></td><td> as dynamic viscosity of liquid [Pa.s],</td></tr>
<tr><td><b> eta_v                        </b></td><td> as dynamic viscosity of vapour [Pa.s],</td></tr>
<tr><td><b> Fr = u^2/(g*d)                </b></td><td> as Froude number [-], </td></tr>
<tr><td><b> G                        </b></td><td> as non dimensional number [-], </td></tr>
<tr><td><b> g                        </b></td><td> as acceleration of gravity [m/s^2],</td></tr>
<tr><td><b> lambda_l                </b></td><td> as heat conductivity of liquid [W/(m.K)],</td></tr>
<tr><td><b> Nu                        </b></td><td> as mean Nusselt number [-], </td></tr>
<tr><td><b> Ph                        </b></td><td> as phase change number [-], </td></tr>
<tr><td><b> Pr = eta*cp/lambda        </b></td><td> as Prandtl number of fluid [-], </td></tr>
<tr><td><b> Re_FS = u*d*rho_l/eta_l        </b></td><td> as Reynolds number [-],</td></tr>
<tr><td><b> r                        </b></td><td> as specific enthalpy of evaporation [kJ/kg], </td></tr>
<tr><td><b> rho_l                        </b></td><td> as density of liquid [kg/m3],</td></tr>
<tr><td><b> rho_v                        </b></td><td> as density of vapour [kg/m3],</td></tr>
<tr><td><b> T_s                        </b></td><td> as saturation temperature of steam [K], </td></tr>
<tr><td><b> T_w                        </b></td><td> as wall temperature [K], </td></tr>
<tr><td><b> u                        </b></td><td> as oncoming velocity of steam [m/s],</td></tr>
<tr><td><b> Xi                        </b></td><td> as non dimensional number [-]. </td></tr>
</table>
</p>

<p>
<b>Please note</b>: According to original paper (Fujii et. al) Reynolds number is calculated with tube diameter <b>d</b> instead of characteristic lentgh of film flow <b>L</b> = (eta_liq^2/rho_liq^2/g)^(1/3) (VDI-Waermeatlas). This improves the comparability with validation data and other equations and has no influence on calculated heat transfer coefficients. 
</p>

<h4><font color=\"#EF9B13\">Verification</font></h4>  
<p>
The mean Nusselt number <b> Nu </b> representing the mean heat transfer coefficient <b> kc </b> is shown below for different temperature differences between vapour and wall for identical dimensions. 
</p>
 
<p>
<img src=\"modelica://FluidDissipation/Extras/Images/heatTransfer/heatExchanger/fig_FilmCondensationTubeBundle_kc.png\">
</p>

<p><b><font style=\"color: #ef9b13; \">References</font></b> </p>
<dl><dt>Mueller, J. and Numrich, R. </dt>
<dd><b>Film Condensation of Pure Vapour</b> (in German). in VDI-Waermeatlas, 9th edition,  VDI-Verlag, 2002.</dd>
<dl><dt>T. Fujii, H.Uehara and C. Kurata </dt>
<dd><b>Laminar Filmwise Condensation of Flowing Vapour on a Horizontal Cylinder</b>. in Int. J. of Heat and Mass Transfer, Vol. 15, pp 235-246,  Pergamon Press, 1972.</dd>
</dl>

<p><b><font style=\"color: #ef9b13; \">References</font></b> </p>
<p>Gnielinski, V.. <b>Heat Transfer in laterally passed single tube rows and tube bundles </b> (in German). in VDI-Waermeatlas, 9th edition, VDI-Verlag, 2002.</p>
</html>"));
end kc_tubeBundle_1ph;
